package sample.redis;

import org.springframework.data.redis.serializer.RedisSerializer;
import org.springframework.data.redis.serializer.SerializationException;

import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.type.TypeFactory;

public class GlueRedisSerializer implements RedisSerializer<Object>
{

    private ObjectMapper objectMapper = new ObjectMapper();

    public Object deserialize( byte[] bytes ) throws SerializationException
    {
        if ( isDataEmpty( bytes ) )
        {
            return null;
        }

        try
        {
            String tmpString = new String( bytes, 0, bytes.length );
            String classString = tmpString.split( "," )[0];
            String jsonString = tmpString.substring( classString.length() + 1 );

            JavaType javaType = TypeFactory.defaultInstance().constructType( Class.forName( classString ) );

            return (Object) this.objectMapper.readValue( jsonString, javaType );
        } catch ( Exception ex )
        {
            throw new SerializationException( "Could not read JSON: " + ex.getMessage(), ex );
        }
    }

    public byte[] serialize( Object object ) throws SerializationException
    {

        if ( object == null )
        {
            return new byte[0];
        }

        try
        {
            String className = object.getClass().getName() + ",";
            byte[] classNameByte = className.getBytes();
            byte[] objectByte = this.objectMapper.writeValueAsBytes( object );
            byte[] result = new byte[classNameByte.length + objectByte.length];
            System.arraycopy( classNameByte, 0, result, 0, classNameByte.length );
            System.arraycopy( objectByte, 0, result, classNameByte.length, objectByte.length );
            return result;
        } catch ( Exception ex )
        {
            throw new SerializationException( "Could not write JSON: " + ex.getMessage(), ex );
        }

    }

    private boolean isDataEmpty( byte[] data )
    {
        return ( data == null || data.length == 0 );
    }

}