package junit;

import java.util.HashMap;
import java.util.Map;

import org.junit.Before;
import org.junit.Test;

import com.poscoict.glueframework.biz.control.GlueBizControlConstants;
import com.poscoict.glueframework.biz.control.GlueBizController;
import com.poscoict.glueframework.biz.control.GlueBizProvider;
import com.poscoict.glueframework.context.GlueContext;
import com.poscoict.glueframework.context.GlueDefaultContext;
import com.poscoict.glueframework.util.log.GlueLog;
import com.poscoict.glueframework.util.log.GlueLogFactory;

public class ActivityTest
{
    /** logger */
    private final GlueLog logger = GlueLogFactory.getLogger( getClass() );

    private GlueContext ctx;
    private GlueBizController bizIF;
    private String serviceName;

    @Before
    public void init()
    {
        bizIF = GlueBizProvider.getController();
    }

    @Test
    public void testRedisActivityValue()
    {

        serviceName = "sample-string-service";
        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "Set", "event" );
        ctx.put( "RedisActivityTest1", "RedisActivityTest1" );
        ctx.put( "RedisActivityValue", "Redis Activity Test Value" );
        bizIF.doAction( ctx );

        logger.info( "testRedisActivity1 RedisGetResult : " + ctx.get( "RedisGetResult" ) );

        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "Delete", "event" );
        ctx.put( "RedisActivityTest1", "RedisActivityTest1" );
        bizIF.doAction( ctx );

        logger.info( "testRedisActivity2 RedisGetResult : " + ctx.get( "RedisGetResult" ) );
    }

    @Test
    public void testRedisActivityList1()
    {
        serviceName = "sample-list-service";
        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "Set", "event" );
        ctx.put( "RedisActivityTestList", "RedisActivityTestList" );
        String[] value = { "test1", "test2", "test3", "test4", "test5", "test6" };
        ctx.put( "RedisActivityValue", value );
        bizIF.doAction( ctx );

        logger.info( "List RedisGetResult : " + ctx.get( "RedisGetResult" ) );

        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "Delete", "event" );
        ctx.put( "RedisActivityTestList", "RedisActivityTestList" );
        bizIF.doAction( ctx );

        logger.info( "List RedisGetResult : " + ctx.get( "RedisGetResult" ) );

    }

    @Test
    public void testRedisActivitySet1()
    {
        serviceName = "sample-set-service";
        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "Set", "event" );
        ctx.put( "RedisActivityTestSet", "RedisActivityTestSet" );
        String[] value = { "testset1", "testset2", "testset3", "testset4", "testset5", "testset6" };
        ctx.put( "RedisActivityValue", value );
        bizIF.doAction( ctx );
        logger.info( "Set RedisGetResult : " + ctx.get( "RedisGetResult" ) );

        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "RedisActivityTestSet", "RedisActivityTestSet" );
        bizIF.doAction( ctx );
        logger.info( "Set RedisGetResult : " + ctx.get( "RedisGetResult" ) );

        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "Delete", "event" );
        ctx.put( "RedisActivityTestSet", "RedisActivityTestSet" );
        bizIF.doAction( ctx );

        logger.info( "Set RedisGetResult : " + ctx.get( "RedisGetResult" ) );

    }

    @Test
    public void testRedisActivityZSet1()
    {
        serviceName = "sample-zset-service";
        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "Set", "event" );
        ctx.put( "RedisActivityTestZSet", "RedisActivityTestZSet" );
        String[] value = { "testset1", "testset2", "testset3", "testset4", "testset5", "testset6" };
        String[] score = { "100", "200", "300", "400", "500", "600" };
        ctx.put( "RedisActivityValue", value );
        ctx.put( "RedisActivityTestScore", score );
        bizIF.doAction( ctx );
        logger.info( "Set RedisGetResult : " + ctx.get( "RedisGetResult" ) );

        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "RedisActivityTestZSet", "RedisActivityTestZSet" );
        bizIF.doAction( ctx );
        logger.info( "Set RedisGetResult : " + ctx.get( "RedisGetResult" ) );

        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "Delete", "event" );
        ctx.put( "RedisActivityTestZSet", "RedisActivityTestZSet" );
        bizIF.doAction( ctx );

        logger.info( "Set RedisGetResult : " + ctx.get( "RedisGetResult" ) );

    }

    @Test
    public void testRedisActivityHash1()
    {
        serviceName = "sample-hash-service";
        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "Set", "event" );
        ctx.put( "RedisActivityTestHash", "RedisActivityTestHash" );

        Map<String, Object> value = new HashMap<String, Object>();

        for ( int i = 0; i < 10; i++ )
        {
            value.put( "testkey" + i, "testvalue" + i );
        }
        ctx.put( "RedisActivityValue", value );
        bizIF.doAction( ctx );

        logger.info( "Set RedisGetResult : " + ctx.get( "RedisGetResult" ) );

        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "RedisActivityTestHash", "RedisActivityTestHash" );
        bizIF.doAction( ctx );
        logger.info( "Set RedisGetResult : " + ctx.get( "RedisGetResult" ) );

        ctx = new GlueDefaultContext();
        ctx.put( GlueBizControlConstants.SERVICE_NAME, serviceName );
        ctx.put( "Delete", "event" );
        ctx.put( "RedisActivityTestHash", "RedisActivityTestHash" );
        bizIF.doAction( ctx );

        logger.info( "Set RedisGetResult : " + ctx.get( "RedisGetResult" ) );

    }
}
