package junit;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.junit.Before;
import org.junit.Test;

import com.poscoict.glueframework.context.GlueStaticContext;
import com.poscoict.glueframework.dao.redis.GlueGenericRedisDao;
import com.poscoict.glueframework.util.log.GlueLog;
import com.poscoict.glueframework.util.log.GlueLogFactory;

public class RedisDaoTest
{
    private GlueGenericRedisDao redisDao;

    /** logger */
    private final GlueLog logger = GlueLogFactory.getLogger( getClass() );

    @Before
    public void init()
    {
        redisDao = (GlueGenericRedisDao) GlueStaticContext.getBeanFactory().getBeanObject( "redisDao" );
        assertNotNull( redisDao );
    }

    @Test
    public void testOpsValue1()
    {
        logger.info( "Set Value start!" );
        redisDao.opsValueSetObject( "opsValueTestKey1", "opsValueSetTestValue" );
        logger.info( "Set Value end!" );

        logger.info( "Get Value start!" );
        String opsValueTestKey1 = (String) redisDao.opsValueGetObject( "opsValueTestKey1" );
        assertNotNull( opsValueTestKey1 );
        assertTrue( opsValueTestKey1.endsWith( "opsValueSetTestValue" ) );
        logger.info( "Get Value end!" );

        logger.info( "delete Value start!" );
        redisDao.delete( "opsValueTestKey1" );
        logger.info( "delete Value end!" );

        opsValueTestKey1 = (String) redisDao.opsValueGetObject( "opsValueTestKey1" );
        assertTrue( opsValueTestKey1 == null );
    }

    @Test
    public void testOpsList1()
    {
        redisDao.delete( "opsListSetTestValue" );

        logger.info( "Set List start!" );
        List<Object> listvalue = new ArrayList<Object>();

        for ( int i = 0; i < 1000; i++ )
        {
            listvalue.add( "test" + i );
        }
        redisDao.opsListAddListAll( "opsListSetTestValue", listvalue );
        redisDao.opsListAddObject( "opsListSetTestValue", "opsListAddObjectTestValue" );
        logger.info( "Set List end!" );

        logger.info( "Get List start!" );
        List<Object> listresult = redisDao.opsListGetList( "opsListSetTestValue" );
        logger.info( "Size:::" + listresult.size() );
        logger.info( "first value:::" + listresult.get( 0 ) );
        logger.info( "last value:::" + listresult.get( listresult.size() - 1 ) );
        assertTrue( listresult.size() == 1001 );
        assertTrue( "test0".equals( listresult.get( 0 ) ) );
        assertTrue( "opsListAddObjectTestValue".equals( listresult.get( 1000 ) ) );

        listresult = redisDao.opsListGetList( "opsListSetTestValue", 10, 100 );
        logger.info( "Size:::" + listresult.size() );
        logger.info( "first value:::" + listresult.get( 0 ) );
        logger.info( "last value:::" + listresult.get( listresult.size() - 1 ) );
        assertTrue( listresult.size() == 91 );
        assertTrue( "test10".equals( listresult.get( 0 ) ) );
        assertTrue( "test100".equals( listresult.get( 90 ) ) );

        logger.info( "Get List end!" );

        logger.info( "delete List start!" );
        redisDao.delete( "opsListSetTestValue" );
        logger.info( "delete List end!" );

        listresult = redisDao.opsListGetList( "opsListSetTestValue" );
        assertTrue( listresult.size() == 0 );
    }

    @Test
    public void testOpsSet1()
    {
        redisDao.delete( "opsSetSetTestValue" );
        logger.info( "Set Set start!" );
        Set<Object> setvalue = new HashSet<Object>();

        for ( int i = 0; i < 1000; i++ )
        {
            setvalue.add( "test" + i );
        }
        redisDao.opsSetAddSet( "opsSetSetTestValue", setvalue );
        redisDao.opsSetAddObject( "opsSetSetTestValue", "opsSetAddObjectTestValue" );
        logger.info( "Set Set end!" );

        logger.info( "Get Set start!" );
        Set<Object> result = redisDao.opsSetGetSet( "opsSetSetTestValue" );
        logger.info( "Size:::" + result.size() );
        assertTrue( result.size() == 1001 );

        logger.info( "Get Set end!" );

        logger.info( "delete Set start!" );
        redisDao.delete( "opsSetSetTestValue" );
        logger.info( "delete Set end!" );

        result = redisDao.opsSetGetSet( "opsSetSetTestValue" );
        assertTrue( result.size() == 0 );
    }

    @Test
    public void testOpsZSet1()
    {
        redisDao.delete( "opsZSetTestValue" );
        logger.info( "Set ZSet start!" );

        for ( int i = 0; i < 1000; i++ )
        {
            redisDao.opsZSetAddObject( "opsZSetTestValue", "testvalue" + i, i * 100 );
        }

        logger.info( "Set ZSet end!" );

        logger.info( "Get ZSet start!" );
        Set<Object> result = redisDao.opsZSetGetSet( "opsZSetTestValue" );
        logger.info( "Size:::" + result.size() );
        assertTrue( result.size() == 1000 );

        result = redisDao.opsZSetGetSet( "opsZSetTestValue", 10, 100 );
        logger.info( "Size:::" + result.size() );
        assertTrue( result.size() == 91 );

        result = redisDao.opsZSetGetSetByScore( "opsZSetTestValue", 100, 200 );
        logger.info( "Size:::" + result.size() );
        assertTrue( result.size() == 2 );

        double score = redisDao.opsZSetGetScore( "opsZSetTestValue", "testvalue2" );
        logger.info( "score:::" + score );
        assertTrue( score == 200 );

        long rank = redisDao.opsZSetRank( "opsZSetTestValue", "testvalue2" );
        logger.info( "rank:::" + rank );
        assertTrue( rank == 2 );

        logger.info( "Get ZSet end!" );

        logger.info( "delete ZSet start!" );
        redisDao.opsZSetRemoveByScore( "opsZSetTestValue", 100, 200 );
        result = redisDao.opsZSetGetSet( "opsZSetTestValue" );
        logger.info( "Size:::" + result.size() );
        assertTrue( result.size() == 998 );

        redisDao.delete( "opsZSetTestValue" );
        result = redisDao.opsSetGetSet( "opsZSetTestValue" );
        assertTrue( result.size() == 0 );

        logger.info( "delete ZSet end!" );

    }

    @Test
    public void testOpsHash1()
    {
        redisDao.delete( "opsHashTestValue" );
        logger.info( "Set Hash start!" );
        Map<String, Object> setvalue = new HashMap<String, Object>();

        for ( int i = 0; i < 1000; i++ )
        {
            setvalue.put( "testkey" + i, "testvalue" + i );
        }
        redisDao.opsHashAddMap( "opsHashTestValue", setvalue );
        redisDao.opsHashAddObject( "opsHashTestValue", "testaddkey", "opsSetAddObjectValue" );
        logger.info( "Set Hash end!" );

        logger.info( "Get Hash start!" );
        Map<String, Object> result = redisDao.opsHashGetMap( "opsHashTestValue" );
        logger.info( "Size:::" + result.size() );
        assertTrue( result.size() == 1001 );

        String valueresult = (String) redisDao.opsHashGetObject( "opsHashTestValue", "testaddkey" );
        logger.info( "testaddkey:::" + valueresult );
        assertTrue( "opsSetAddObjectValue".equals( valueresult ) );

        Set<String> resultkey = redisDao.opsHashKeys( "opsHashTestValue" );
        logger.info( "HashKeys:::" + resultkey );
        logger.info( "Get Hash end!" );

        logger.info( "delete Hash start!" );
        redisDao.delete( "opsHashTestValue" );
        logger.info( "delete Hash end!" );

        result = redisDao.opsHashGetMap( "opsHashTestValue" );
        assertTrue( result.size() == 0 );
    }

}