package junit;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.util.Date;

import org.junit.Test;

import sample.vo.UserSerializable;
import sample.vo.UserVo;

import com.poscoict.glueframework.context.GlueStaticContext;
import com.poscoict.glueframework.dao.redis.GlueGenericRedisDao;
import com.poscoict.glueframework.util.log.GlueLog;
import com.poscoict.glueframework.util.log.GlueLogFactory;

public class RedisSeriallzerTest
{
    private GlueGenericRedisDao redisDao;

    /** logger */
    private final GlueLog logger = GlueLogFactory.getLogger( getClass() );

    @Test
    public void testDefaultSeriallzer()
    {
        redisDao = (GlueGenericRedisDao) GlueStaticContext.getBeanFactory().getBeanObject( "redisDao" );
        assertNotNull( redisDao );

        UserSerializable user = new UserSerializable( "testid1", "cho", "chang", new Date() );

        logger.info( "Set Value start!" );
        redisDao.opsValueSetObject( "SerializableUser1", user );
        logger.info( "Set Value end!" );

        logger.info( "Get Value start!" );
        UserSerializable getuser = (UserSerializable) redisDao.opsValueGetObject( "SerializableUser1" );
        assertNotNull( getuser );
        logger.info( "SerializableUser1 : {}", getuser.toString() );
        logger.info( "Get Value end!" );

        logger.info( "delete Value start!" );
        redisDao.delete( "SerializableUser1" );
        logger.info( "delete Value end!" );

        getuser = (UserSerializable) redisDao.opsValueGetObject( "SerializableUser1" );
        assertTrue( getuser == null );
    }

    @Test
    public void testJsonSeriallzer()
    {

        redisDao = (GlueGenericRedisDao) GlueStaticContext.getBeanFactory().getBeanObject( "redisDaoJson" );
        assertNotNull( redisDao );

        UserVo user = new UserVo( "testid2", "cho2", "chang2", new Date() );

        logger.info( "Set Value start!" );
        redisDao.opsValueSetObject( "JsonUser1", user );
        logger.info( "Set Value end!" );

        logger.info( "Get Value start!" );
        UserVo getuser = (UserVo) redisDao.opsValueGetObject( "JsonUser1" );
        assertNotNull( getuser );
        logger.info( "JsonUser1 : {}", getuser.toString() );
        logger.info( "Get Value end!" );

        logger.info( "delete Value start!" );
        redisDao.delete( "JsonUser1" );
        logger.info( "delete Value end!" );

        getuser = (UserVo) redisDao.opsValueGetObject( "JsonUser1" );
        assertTrue( getuser == null );

    }

    @Test
    public void testCustomSeriallzer()
    {
        redisDao = (GlueGenericRedisDao) GlueStaticContext.getBeanFactory().getBeanObject( "redisDaoCustom" );
        assertNotNull( redisDao );

        UserVo user = new UserVo( "testid3", "cho3", "chang3", new Date() );

        logger.info( "Set Value start!" );
        redisDao.opsValueSetObject( "CustomUser1", user );
        logger.info( "Set Value end!" );

        logger.info( "Get Value start!" );
        UserVo getuser = (UserVo) redisDao.opsValueGetObject( "CustomUser1" );
        assertNotNull( getuser );
        logger.info( "CustomUser1 : {}", getuser.toString() );
        logger.info( "Get Value end!" );

        logger.info( "delete Value start!" );
        redisDao.delete( "CustomUser1" );
        logger.info( "delete Value end!" );

        getuser = (UserVo) redisDao.opsValueGetObject( "CustomUser1" );
        assertTrue( getuser == null );
    }
}